@@ -81,7 +81,7 @@ compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data
 	gtk_tree_model_get_value (model, b, SORT_DATA_COLUMN, &val_b);
 	str_b = g_value_get_string (&val_b);
 
-	cmp = g_ascii_strcasecmp (str_a, str_b);
+	cmp = g_ascii_strcasecmp (str_a?str_a:"", str_b?str_b:"");
 	
 	g_value_unset (&val_a);
 	g_value_unset (&val_b);
@@ -356,7 +356,7 @@ foreach_cb (gchar *category, gchar *desc, GList *events, SoundView *view)
 		gtk_tree_store_set (GTK_TREE_STORE (view->priv->model), &child_iter,
 				    EVENT_COLUMN, event->desc,
 				    FILE_COLUMN, event->file,
-				    SORT_DATA_COLUMN, event->desc,
+				    SORT_DATA_COLUMN, event->desc?event->desc:"",
 				    TYPE_COLUMN, (guint) EVENT,
 				    DATA_COLUMN, event,
 				    -1);
